Configuration · Chart.js documentation
Author: chartjs

# Configuration

The configuration is used to change how the chart behaves. There are properties to control styling, fonts, the legend, etc.

## Global Configuration

This concept was introduced in Chart.js 1.0 to keep configuration DRY, and allow for changing options globally across chart types, avoiding the need to specify options for each instance, or the default for a particular chart type.

Chart.js merges the options object passed to the chart with the global configuration using chart type defaults and scales defaults appropriately. This way you can be as specific as you would like in your individual chart configuration, while still changing the defaults for all chart types where applicable. The global general options are defined in `Chart.defaults.global`. The defaults for each chart type are discussed in the documentation for that chart type.

The following example would set the hover mode to 'nearest' for all charts where this was not overridden by the chart type defaults or the options passed to the constructor on creation.

    Chart.defaults.global.hover.mode = 'nearest';

    // Hover mode is set to nearest because it was not overridden here
    var chartHoverModeNearest  = new Chart(ctx, {
        type: 'line',
        data: data,
    });

    // This chart would have the hover mode that was passed in
    var chartDifferentHoverMode = new Chart(ctx, {
        type: 'line',
        data: data,
        options: {
            hover: {
                // Overrides the global setting
                mode: 'index'
            }
        }
    })

# results matching ""

# No results matching ""